# coding: utf-8

"""
    Mentortools Telegram Assistant API

    Mentortools telegram assistant connector

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from telegram_assistant_connector.api.telegram_connector_api import TelegramConnectorApi  # noqa: E501


class TestTelegramConnectorApi(unittest.IsolatedAsyncioTestCase):
    """TelegramConnectorApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = TelegramConnectorApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_telegram_connector_send_authorization_message(self) -> None:
        """Test case for telegram_connector_send_authorization_message

        Send authorization message  # noqa: E501
        """
        pass

    async def test_telegram_connector_send_message(self) -> None:
        """Test case for telegram_connector_send_message

        Send message  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
