# coding: utf-8

# flake8: noqa

"""
    Mentortools Telegram Assistant API

    Mentortools telegram assistant connector

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.1.0+2399831551"

# Define package exports
__all__ = [
    "DefaultApi",
    "TelegramConnectorApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "HTTPValidationError",
    "LocationInner",
    "SendMessagePayload",
    "ValidationError",
    "WrappedResponseBool",
    "WrappedResponseInt",
]

# import apis into sdk package
from telegram_assistant_connector.api.default_api import DefaultApi as DefaultApi
from telegram_assistant_connector.api.telegram_connector_api import TelegramConnectorApi as TelegramConnectorApi

# import ApiClient
from telegram_assistant_connector.api_response import ApiResponse as ApiResponse
from telegram_assistant_connector.api_client import ApiClient as ApiClient
from telegram_assistant_connector.configuration import Configuration as Configuration
from telegram_assistant_connector.exceptions import OpenApiException as OpenApiException
from telegram_assistant_connector.exceptions import ApiTypeError as ApiTypeError
from telegram_assistant_connector.exceptions import ApiValueError as ApiValueError
from telegram_assistant_connector.exceptions import ApiKeyError as ApiKeyError
from telegram_assistant_connector.exceptions import ApiAttributeError as ApiAttributeError
from telegram_assistant_connector.exceptions import ApiException as ApiException

# import models into sdk package
from telegram_assistant_connector.models.http_validation_error import HTTPValidationError as HTTPValidationError
from telegram_assistant_connector.models.location_inner import LocationInner as LocationInner
from telegram_assistant_connector.models.send_message_payload import SendMessagePayload as SendMessagePayload
from telegram_assistant_connector.models.validation_error import ValidationError as ValidationError
from telegram_assistant_connector.models.wrapped_response_bool import WrappedResponseBool as WrappedResponseBool
from telegram_assistant_connector.models.wrapped_response_int import WrappedResponseInt as WrappedResponseInt
