# coding: utf-8

"""
    Mentortools Telegram Assistant API

    Mentortools telegram assistant connector

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from telegram_assistant_connector.models.send_message_payload import SendMessagePayload  # noqa: E501

class TestSendMessagePayload(unittest.TestCase):
    """SendMessagePayload unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SendMessagePayload:
        """Test SendMessagePayload
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SendMessagePayload`
        """
        model = SendMessagePayload()  # noqa: E501
        if include_optional:
            return SendMessagePayload(
                user_id = 56,
                text = '',
                attachments = [
                    ''
                    ]
            )
        else:
            return SendMessagePayload(
                user_id = 56,
                text = '',
        )
        """

    def testSendMessagePayload(self):
        """Test SendMessagePayload"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
