# coding: utf-8

# flake8: noqa
"""
    Mentortools Telegram Assistant API

    Mentortools telegram assistant connector

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from telegram_assistant_connector.models.http_validation_error import HTTPValidationError
from telegram_assistant_connector.models.location_inner import LocationInner
from telegram_assistant_connector.models.send_message_payload import SendMessagePayload
from telegram_assistant_connector.models.validation_error import ValidationError
from telegram_assistant_connector.models.wrapped_response_bool import WrappedResponseBool
from telegram_assistant_connector.models.wrapped_response_int import WrappedResponseInt
